==> php-doctrine-cache_1.3.0.orig.tar.gz: cache-1.3.0/tests/Doctrine/Tests/Common/Cache/MemcachedCacheTest.php <==
<?php

namespace Doctrine\Tests\Common\Cache;

use Doctrine\Common\Cache\MemcachedCache;
use Memcached;

class MemcachedCacheTest extends CacheTest
{
    private $memcached;

    public function setUp()
    {
        if ( ! extension_loaded('memcached')) {
            $this->markTestSkipped('The ' . __CLASS__ .' requires the use of memcached');
        }

        $this->memcached = new Memcached();
        $this->memcached->setOption(Memcached::OPT_COMPRESSION, false);
        $this->memcached->addServer('127.0.0.1', 11211);

        if (@fsockopen('127.0.0.1', 11211) === false) {
            unset($this->memcached);
            $this->markTestSkipped('The ' . __CLASS__ .' cannot connect to memcache');
        }
    }

    public function tearDown()
    {
        if ($this->memcached instanceof Memcached) {
            $this->memcached->flush();
        }
    }

    public function testNoExpire()
    {
        $cache = $this->_getCacheDriver();
        $cache->save('noexpire', 'value', 0);
        sleep(1);
        $this->assertTrue($cache->contains('noexpire'), 'Memcache provider should support no-expire');
    }

    public function testLongLifetime()
    {
        $cache = $this->_getCacheDriver();
        $cache->save('key', 'value', 30 * 24 * 3600 + 1);
        $this->assertTrue($cache->contains('key'), 'Memcache provider should support TTL > 30 days');
    }

    protected function _getCacheDriver()
    {
        $driver = new MemcachedCache();
        $driver->setMemcached($this->memcached);
        return $driver;
    }
}

==> php-doctrine-cache_1.4.1.orig.tar.gz: cache-1.4.1/tests/Doctrine/Tests/Common/Cache/MemcachedCacheTest.php <==
<?php

namespace Doctrine\Tests\Common\Cache;

use Doctrine\Common\Cache\MemcachedCache;
use Memcached;

class MemcachedCacheTest extends CacheTest
{
    private $memcached;

    public function setUp()
    {
        if ( ! extension_loaded('memcached')) {
            $this->markTestSkipped('The ' . __CLASS__ .' requires the use of memcached');
        }

        $this->memcached = new Memcached();
        $this->memcached->setOption(Memcached::OPT_COMPRESSION, false);
        $this->memcached->addServer('127.0.0.1', 11211);

        if (@fsockopen('127.0.0.1', 11211) === false) {
            unset($this->memcached);
            $this->markTestSkipped('The ' . __CLASS__ .' cannot connect to memcache');
        }
    }

    public function tearDown()
    {
        if ($this->memcached instanceof Memcached) {
            $this->memcached->flush();
        }
    }

    public function testNoExpire()
    {
        $cache = $this->_getCacheDriver();
        $cache->save('noexpire', 'value', 0);
        sleep(1);
        $this->assertTrue($cache->contains('noexpire'), 'Memcache provider should support no-expire');
    }

    public function testLongLifetime()
    {
        $cache = $this->_getCacheDriver();
        $cache->save('key', 'value', 30 * 24 * 3600 + 1);
        $this->assertTrue($cache->contains('key'), 'Memcache provider should support TTL > 30 days');
    }

    protected function _getCacheDriver()
    {
        $driver = new MemcachedCache();
        $driver->setMemcached($this->memcached);
        return $driver;
    }

    /**
     * {@inheritDoc}
     *
     * @dataProvider falseCastedValuesProvider
     */
    public function testFalseCastedValues($value)
    {
        if (false === $value) {
            $this->markTestIncomplete('Memcached currently doesn\'t support saving `false` values. ');
        }

        parent::testFalseCastedValues($value);
    }
}
